@@ -2,13 +2,14 @@ package Alien::Build::Plugin::Test::Mock;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use Carp ();
 use Path::Tiny ();
 use File::chdir;
 
 # ABSTRACT: Mock plugin for testing
-our $VERSION = '1.98'; # VERSION
+our $VERSION = '2.38'; # VERSION
 
 
 has 'probe';
@@ -258,7 +259,7 @@ Alien::Build::Plugin::Test::Mock - Mock plugin for testing
 
 =head1 VERSION
 
-version 1.98
+version 2.38
 
 =head1 SYNOPSIS
 
@@ -429,6 +430,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
