@@ -2,7 +2,7 @@ package Test::Alien;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.008004;
 use Env qw( @PATH );
 use File::Which 1.10 qw( which );
 use Capture::Tiny qw( capture capture_merged );
@@ -18,7 +18,7 @@ use Config;
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic helper_ok interpolate_template_is );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '1.98'; # VERSION
+our $VERSION = '2.38'; # VERSION
 
 
 our @aliens;
@@ -193,7 +193,7 @@ sub xs_ok
   my @diag;
   my $dir = Alien::Build::Temp->newdir(
     TEMPLATE => 'test-alien-XXXXXX',
-    CLEANUP  => $^O eq 'MSWin32' ? 0 : 1,
+    CLEANUP  => $^O =~ /^(MSWin32|cygwin)$/ ? 0 : 1,
   );
   my $xs_filename = path($dir)->child('test.xs')->stringify;
   my $c_filename  = path($dir)->child("test.@{[ $xs->{c_ext} ]}")->stringify;
@@ -205,7 +205,8 @@ sub xs_ok
   {
     our $count;
     $count = 0 unless defined $count;
-    my $name = sprintf "Test::Alien::XS::Mod%s", $count++;
+    my $name = sprintf "Test::Alien::XS::Mod%s%s", $count, chr(65 + $count % 26 ) x 4;
+    $count++;
     my $code = $xs->{xs};
     $code =~ s{\bTA_MODULE\b}{$name}g;
     $xs->{xs} = $code;
@@ -267,7 +268,7 @@ sub xs_ok
       config => do {
         my %config = %{ $xs->{cbuilder_config} };
         my $lddlflags = join(' ', grep !/^-l/, shellwords map { _flags $_, 'libs' } @aliens) . " $Config{lddlflags}";
-        $config{lddlflags} = defined $config{lddlflags} ? "$config{lddlflags} $lddlflags" : $lddlflags;
+        $config{lddlflags} = defined $config{lddlflags} ? "$lddlflags $config{lddlflags}" : $lddlflags;
         \%config;
       },
     );
@@ -654,7 +655,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 1.98
+version 2.38
 
 =head1 SYNOPSIS
 
@@ -1057,6 +1058,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
