@@ -2,6 +2,7 @@ package alienfile;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build;
 use base qw( Exporter );
 use Path::Tiny ();
@@ -10,7 +11,7 @@ use Carp ();
 sub _path { Path::Tiny::path(@_) }
 
 # ABSTRACT: Specification for defining an external dependency for CPAN
-our $VERSION = '2.23'; # VERSION
+our $VERSION = '2.38'; # VERSION
 
 
 our @EXPORT = qw( requires on plugin probe configure share sys download fetch decode prefer extract patch patch_ffi build build_ffi gather gather_ffi meta_prop ffi log test start_url before after );
@@ -368,7 +369,7 @@ alienfile - Specification for defining an external dependency for CPAN
 
 =head1 VERSION
 
-version 2.23
+version 2.38
 
 =head1 SYNOPSIS
 
@@ -508,7 +509,7 @@ Examples:
  plugin '=Badly::Named::Plugin::Not::In::Alien::Build::Namespace';
  
  # explicitly loads Alien::Build::Plugin::Prefer::SortVersions
- plugin 'Prefer::SortVersions => (
+ plugin 'Prefer::SortVersions' => (
    filter => qr/^gcc-.*\.tar\.gz$/,
    version => qr/([0-9\.]+)/,
  );
@@ -839,6 +840,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
